﻿namespace Phoenix.Model.Bll.Domain
{
    /// <summary>
    /// Represent a relation between two members of a family
    /// </summary>
    public class Relation : Poco
    {
        #region Properties

        /// <summary>
        /// Gets or sets the patient involved in the relation.
        /// </summary>
        /// <value>The patient.</value>
        public virtual Patient Member
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the remark on this relation.
        /// </summary>
        /// <value>The remark.</value>
        public virtual string Remark
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the link of the relation.
        /// </summary>
        /// <value>The link.</value>
        public virtual RelationType Type
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the upside down relation. That's,
        /// the relation seen from the opposite.
        /// </summary>
        /// <value>The upside down.</value>
        public virtual Relation UpsideDown
        {
            get;
            set;
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Returns a <see cref="System.String"/> that represents this instance.
        /// </summary>
        /// <returns>
        /// A <see cref="System.String"/> that represents this instance.
        /// </returns>
        public override string ToString()
        {
            return string.Format("[{0}] {1}", this.Type, this.Member);
        }

        #endregion Methods
    }
}