﻿namespace Phoenix.Model.Bll.Domain
{
    public class User : Poco
    {
        #region Fields

        private decimal fee = 0;
        private string firstName = string.Empty;
        private string header = "This is the default user. Please configure one";
        private bool isDefault = true;
        private string lastName = string.Empty;
        private Practice mainPractice;
        private string password = string.Empty;

        #endregion Fields

        #region Constructors

        public User()
        {
            this.MainPractice = new Practice()
            {
                Address = new Address(),
                Phone = string.Empty,
                Title = "N.A.",
            };
        }

        #endregion Constructors

        #region Properties

        /// <summary>
        /// Gets or sets the default fee the patient have to pay.
        /// </summary>
        /// <value>The fee.</value>
        public virtual decimal Fee
        {
            get
            {
                return this.fee;
            }
            set
            {
                this.Set(this, "Fee", ref fee, value);
            }
        }

        /// <summary>
        /// Gets or sets the first name.
        /// </summary>
        /// <value>The first name.</value>
        public virtual string FirstName
        {
            get { return this.firstName; }
            set { this.Set(this, "FirstName", ref firstName, value); }
        }

        /// <summary>
        /// Gets the full name.
        /// </summary>
        /// <value>The full name.</value>
        public virtual string FullName
        {
            get
            {
                return string.Format("{0} {1}"
                    , this.FirstName
                    , this.LastName.ToUpper());
            }
        }

        /// <summary>
        /// Gets or sets the header. In other words, it is the title of the user.
        /// </summary>
        /// <value>The header.</value>
        public virtual string Header
        {
            get { return this.header; }
            set { this.Set(this, "header", ref header, value); }
        }

        /// <summary>
        /// Gets or sets a value indicating whether this <see cref="User"/> is the
        /// default user of the application.
        /// </summary>
        /// <value><c>true</c> if default; otherwise, <c>false</c>.</value>
        public virtual bool IsDefault
        {
            get { return this.isDefault; }
            set { this.Set(this, "isDefault", ref isDefault, value); }
        }

        /// <summary>
        /// Gets or sets the last name.
        /// </summary>
        /// <value>The last name.</value>
        public virtual string LastName
        {
            get { return this.lastName; }
            set
            {
                this.Set(this, "lastName", ref lastName, value);
            }
        }

        /// <summary>
        /// Gets or sets the main practice.
        /// </summary>
        /// <value>The main practice.</value>
        public virtual Practice MainPractice
        {
            get { return mainPractice; }
            set { this.Set(this, "mainPractice", ref mainPractice, value); }
        }

        /// <summary>
        /// Gets or sets the password.
        /// </summary>
        /// <value>The password.</value>
        public virtual string Password
        {
            get { return this.password; }
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Decrypts this instance.
        /// </summary>
        /// <returns></returns>
        public virtual string DecryptPassword()
        {
            return Encryptor.Decrypt(this.password);
        }

        /// <summary>
        /// Encrypts the specified password.
        /// </summary>
        /// <param name="password">The password.</param>
        public virtual void Encrypt(string password)
        {
            this.password = Encryptor.Encrypt(password);
        }

        /// <summary>
        /// Returns a <see cref="System.String"/> that represents this instance.
        /// </summary>
        /// <returns>
        /// A <see cref="System.String"/> that represents this instance.
        /// </returns>
        public override string ToString()
        {
            return this.FirstName + " " + this.LastName;
        }

        #endregion Methods
    }
}