﻿namespace Phoenix.Model.Core.Management
{
    using System;
    using System.Linq;

    using Phoenix.Model.Bll.Domain;
    using Phoenix.Model.Bll.Interface;
    using Phoenix.Model.Dal;
    using Phoenix.Presenter.Interfaces;

    /// <summary>
    /// All the business logic of the meetings are processed here
    /// </summary>
    public class CalendarModel
    {
        #region Fields

        private IMeetingRepository meetingRepository = RepositoryFactory.Get<IMeetingRepository>();
        private IPatientRepository patientRepository = RepositoryFactory.Get<IPatientRepository>();
        private ICalendarPresenter presenter;
        private IWorkMeetingRepository workMeetingRepository = RepositoryFactory.Get<IWorkMeetingRepository>();

        #endregion Fields

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="CalendarModel"/> class.
        /// </summary>
        /// <param name="presenter">The presenter.</param>
        public CalendarModel(ICalendarPresenter presenter)
        {
            this.presenter = presenter;
            this.presenter.Displaying += (sender, e) => this.Refresh(e.Data1, e.Data2);
            this.presenter.Updated += (sender, e) => this.Update(e.Data);
            this.presenter.MeetingUpdated += (sender, e) => this.Update(e.Data);
            this.presenter.MeetingDeleted += (sender, e) => this.Delete(e.Data);
        }

        #endregion Constructors

        #region Methods

        private void Delete(Meeting meeting)
        {
            this.meetingRepository.Delete(meeting);
        }

        private void Refresh(DateTime startDate, DateTime endDate)
        {
            var workMeetings = this.workMeetingRepository.GetMeetings(startDate, endDate);
            var meetings = this.meetingRepository.GetMeetings(startDate, endDate);

            workMeetings = (from m in workMeetings
                            orderby m.StartDate ascending
                            select m).ToList();

            meetings = (from m in meetings
                        orderby m.StartDate ascending
                        select m).ToList();

            this.presenter.Display(workMeetings, meetings);
        }

        private void Update(Meeting meeting)
        {
            this.meetingRepository.CreateOrUpdate(meeting);
        }

        private void Update(Patient patient)
        {
            this.patientRepository.Update(patient);
        }

        #endregion Methods
    }
}