﻿namespace Phoenix.Model.Core.Management
{
    using System;

    using Phoenix.Helpers.Misc;
    using Phoenix.Model.Bll.Domain;
    using Phoenix.Model.Bll.Interface;
    using Phoenix.Model.Dal;
    using Phoenix.Presenter.Interfaces.Manager;
    using Phoenix.Translation;

    /// <summary>
    /// Manage pathologic events.
    /// </summary>
    public class PathologicEventCreatorModel
    {
        #region Fields

        private IPathologicEventRepository eventRepository = RepositoryFactory.Get<IPathologicEventRepository>();
        private IPatientRepository patientRepository = RepositoryFactory.Get<IPatientRepository>();
        private IPathologicEventCreatorPresenter presenter;
        private IPathologyTypeRepository ptypeRepository = RepositoryFactory.Get<IPathologyTypeRepository>();

        #endregion Fields

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="PathologicEventCreatorModel"/> class.
        /// </summary>
        /// <param name="presenter">The presenter.</param>
        public PathologicEventCreatorModel(IPathologicEventCreatorPresenter presenter)
        {
            this.presenter = presenter;
            this.presenter.TypeSelected += presenter_TypeSelected;
            this.presenter.Refreshed += (sender, e) => this.Refresh();
        }

        #endregion Constructors

        #region Methods

        /// <summary>
        /// Validates the data.
        /// </summary>
        /// <param name="item">The item.</param>
        /// <returns></returns>
        public bool ValidateData(PathologicEvent item)
        {
            var isValidated = true;
            if ((item.EndDate < item.StartDate))
            {
                this.presenter.SetError(PathologicEventFailedOn.EndDateBeforeStartDate
                    , "The end date is before the start date.".Translate());
                isValidated = false;

            }
            if (item.Pathology == null)
            {
                this.presenter.SetError(PathologicEventFailedOn.WithoutPathology
                    , "There is no pathology in the event.");
                isValidated = false;
            }
            if (item.Pathology != null && item.Pathology.Type == null)
            {
                this.presenter.SetError(PathologicEventFailedOn.WithoutPathologyType
                    , "The pathology type is not set.");
                isValidated = false;
            }
            if (item.EndDate > DateTime.Today.AddDays(1) && item.EndDate > DateTime.Today.AddDays(1))
            {
                this.presenter.SetError(PathologicEventFailedOn.DateInFuture
                    , "At least in of the date is in the future");
                isValidated = false;
            }

            return isValidated;
        }

        private void presenter_TypeSelected(object sender, EventArgs<PathologyType> e)
        {
            this.presenter.Pathologies = this.eventRepository.FindByType(e.Data);
        }

        private void Refresh()
        {
            this.presenter.PathologyTypes = ptypeRepository.GetAllRows();
        }

        #endregion Methods
    }
}