﻿namespace Phoenix.Model.Management
{
    using Phoenix.Model.Bll.Interface;
    using Phoenix.Model.Dal;
    using Phoenix.Presenter.Interfaces.Manager;

    /// <summary>
    /// Presenter of the MVP. Manage the business logic of the picture manager
    /// </summary>
    public class PictureModel
    {
        #region Fields

        private IPictureManagerPresenter presenter;
        private IPatientRepository repository = RepositoryFactory.Get<IPatientRepository>();

        #endregion Fields

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="PictureModel"/> class.
        /// </summary>
        /// <param name="presenter">The view.</param>
        public PictureModel(IPictureManagerPresenter presenter)
        {
            this.presenter = presenter;
            this.presenter.Inserted += (sender, e) =>
            {
                this.presenter.Patient.Add(e.Data);
                this.repository.Update(this.presenter.Patient);
            };
            this.presenter.Updated += (sender, e) => this.repository.Update(this.presenter.Patient);
            this.presenter.Deleted += (sender, e) =>
            {
                this.presenter.Patient.Remove(e.Data);
                this.repository.Update(this.presenter.Patient);
            };
        }

        #endregion Constructors
    }
}