﻿namespace Phoenix.Model.Management
{
    using Phoenix.Model.Bll.Domain;
    using Phoenix.Model.Bll.Interface;
    using Phoenix.Model.Dal;
    using Phoenix.Presenter;
    using Phoenix.Presenter.Interfaces.Input;

    /// <summary>
    /// Presenter part of the MVP
    /// </summary>
    public class RelationModel : Manager<Patient>
    {
        #region Fields

        private IRelationInputPresenter presenter;
        private IRelationRepository relationRepository = RepositoryFactory.Get<IRelationRepository>();
        private IRelationTypeRepository relationTypeRepository = RepositoryFactory.Get<IRelationTypeRepository>();

        #endregion Fields

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="RelationModel"/> class.
        /// </summary>
        /// <param name="presenter">The view.</param>
        public RelationModel(IRelationInputPresenter presenter)
            : base(RepositoryFactory.Get<IPatientRepository>())
        {
            this.presenter = presenter;
        }

        #endregion Constructors

        #region Methods

        /// <summary>
        /// Refreshes the data.
        /// </summary>
        public void RefreshData()
        {
            this.presenter.Relations = this.relationTypeRepository.GetAllRows(OrderBy.ASC);
        }

        /// <summary>
        /// Validates the data.
        /// </summary>
        /// <returns></returns>
        public override bool ValidateData()
        {
            bool result = true;
            if (this.presenter.SelectedRelation.Member.IsEmpty
                || this.presenter.SelectedRelation.Member == null)
            {
                this.presenter.SetError(RelationFailedOn.NoParent, "The relation doesn't have a parent.");
                result = false;
            }
            if (this.presenter.SelectedRelation.Type.IsEmpty
                || this.presenter.SelectedRelation.Type == null)
            {
                this.presenter.SetError(RelationFailedOn.NoRelationType, "The relation doesn't have any type");
                result = false;
            }
            return result;
        }

        #endregion Methods
    }
}