﻿namespace Phoenix.Model.Dal.Repositories
{
    using System.Linq;

    using NHibernate.Linq;

    using Phoenix.Model.Bll.Domain;
    using Phoenix.Model.Bll.Interface;

    /// <summary>
    /// Provides CRUD features for an insurance
    /// </summary>
    public class InsuranceRepository : Repository<Insurance>, IInsuranceRepository
    {
        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="InsuranceRepository"/> class.
        /// </summary>
        public InsuranceRepository()
            : base("Insurance", "Title")
        {
        }

        #endregion Constructors

        #region Methods

        /// <summary>
        /// Determines whether the specified item is referenced.
        /// </summary>
        /// <param name="item">The item.</param>
        /// <returns>
        /// 	<c>true</c> if the specified item is referenced; otherwise, <c>false</c>.
        /// </returns>
        public override bool IsReferenced(Insurance item)
        {
            return (from Patient p in this.Session.Linq<Patient>()
                    where p.Insurance == item
                    select p).Count() > 0;
        }

        #endregion Methods
    }
}