﻿namespace Phoenix.Plugins.Core
{
    using System;

    #region Enumerations

    /// <summary>
    /// List of the menu of nDoctor main form
    /// </summary>
    public enum Menus
    {
        /// <summary>
        /// Menu 'File'
        /// </summary>
        File,
        /// <summary>
        /// Menu 'View'
        /// </summary>
        View,
        /// <summary>
        /// Menu 'Session'
        /// </summary>
        Session,
        /// <summary>
        /// Menu 'Tools'
        /// </summary>
        Tools,
        /// <summary>
        /// Menu 'Help'
        /// </summary>
        Help,
    }

    #endregion Enumerations

    public interface IPluginHost
    {
        #region Methods

        /// <summary>
        /// Adds a new menu.
        /// </summary>
        /// <param name="key">The key of the menu.</param>
        /// <param name="text">The text to dispay to the menu.</param>
        /// <param name="onClick">The process to execute when the menu is triggered.</param>   
        /// <returns><c>True</c> if added; otherwise <c>False</c></returns>
        bool AddMenu(string key, string text, Action<object, EventArgs> onClick);

        /// <summary>
        /// Adds a new menu.
        /// </summary>
        /// <param name="key">The key of the menu.</param>
        /// <param name="text">The text to dispay to the menu.</param> 
        /// <returns><c>True</c> if added; otherwise <c>False</c></returns>
        bool AddMenu(string key, string text);

        /// <summary>
        /// Adds a separator to the menu with the specified key.
        /// </summary>
        /// <param name="menuName">Name of the menu.</param>
        /// <returns><c>True</c> if the sperator is added to the menu; otherwise <c>False</c></returns>
        bool AddMenuSeparator(string menuName);

        /// <summary>
        /// Adds a new side menu.
        /// </summary>
        /// <param name="key">The key of the SideMenu item.</param>
        /// <param name="text">The text displayed on the SideMenu item.</param>
        /// <param name="gui">The GUI item displayed in the SideMenu item to add.</param>
        /// <returns><c>True</c> if added; otherwise <c>False</c></returns>
        bool AddSideMenu(string key, string text, object gui);

        /// <summary>
        /// Adds a new submenu at the specified menu. If the menu doesn't exist, creates a new one
        /// </summary>
        /// <param name="menuName">The name of the menu as the unique name to find it.</param>
        /// <param name="submenuKey">The submenu key.</param>
        /// <param name="text">The text to display on the menu.</param>
        /// <param name="onClick">The process to execute when the menu is triggered.</param>   
        /// <returns><c>True</c> if added; otherwise <c>False</c></returns>
        bool AddSubmenu(string menuName, string submenuKey, string text, Action<object, EventArgs> onClick);

        /// <summary>
        /// Adds a new submenu at the specified menu. If the menu doesn't exist, creates a new one
        /// </summary>
        /// <param name="menus">The submenu will be inserted to this menu.</param>
        /// <param name="submenuKey">The submenu key.</param>
        /// <param name="text">The text to display on the menu.</param>
        /// <param name="onClick">The process to execute when the menu is triggered.</param>
        /// <returns>
        /// 	<c>True</c> if added; otherwise <c>False</c>
        /// </returns>
        bool AddSubmenu(Menus menus, string submenuKey, string text, Action<object, EventArgs> onClick);

        /// <summary>
        /// Loads the plugins.
        /// </summary>
        void LoadPlugins();

        /// <summary>
        /// Removes the menu and all its submenus with the specified key.
        /// </summary>
        /// <param name="key">The key.</param>
        /// <returns><c>True</c> if removed; otherwise <c>False</c></returns>
        bool RemoveMenu(string key);

        /// <summary>
        /// Removes the SideMenu item with the specified key.
        /// </summary>
        /// <param name="key">The key.</param>
        /// <returns><c>True</c> if removed; otherwise <c>False</c></returns>
        bool RemoveSideMenu(string key);

        /// <summary>
        /// Removes the submenu with the specified key.
        /// </summary>
        /// <param name="menuKey">The menu key.</param>
        /// <param name="submenuKey">The submenu key.</param>
        /// <returns><c>True</c> if removed; otherwise <c>False</c></returns>
        bool RemoveSubmenu(string menuKey, string submenuKey);

        #endregion Methods
    }
}