﻿namespace Phoenix.Plugins.Manager
{
    using System;
    using System.Diagnostics;
    using System.IO;
    using System.Windows.Forms;

    using log4net;

    using Phoenix.Helpers.Winforms;
    using Phoenix.Plugins.Core;

    public partial class fr_Main : Form
    {
        #region Fields

        private ILog logger = LogManager.GetLogger(typeof(fr_Main));
        private PluginManager pluginManager;

        #endregion Fields

        #region Constructors

        public fr_Main()
        {
            InitializeComponent();
            var path = Path.Combine(Application.StartupPath, "Plugins");
            this.pluginManager = new PluginManager(path);
        }

        #endregion Constructors

        #region Methods

        private void ClearGui()
        {
            this.lv_Plugins.Items.Clear();
            this.tb_Description.Text = "Plugin's description";
        }

        private void cms_Context_Opening(object sender, System.ComponentModel.CancelEventArgs e)
        {
            if (this.lv_Plugins.SelectedItems.Count == 0) e.Cancel = true;
        }

        private void fr_Main_Load(object sender, EventArgs e)
        {
            this.RefreshGui();
        }

        private void HandleError(Exception ex)
        {
            this.logger.Error(ex);
            MessageBoxes.Error(ex.Message);
        }

        private void lv_Plugins_SelectedIndexChanged(object sender, EventArgs e)
        {
            try
            {
                if (this.lv_Plugins.SelectedItems.Count == 0) return;

                var plugin = (PluginManager.PluginInfo)this.lv_Plugins.SelectedItems[0].Tag;
                this.tb_Description.Text = plugin.Description;
            }
            catch (Exception ex)
            {
                this.HandleError(ex);
            }
        }

        private void RefreshGui()
        {
            try
            {
                this.ClearGui();

                foreach (var info in this.pluginManager.GetPluginsInfo())
                {
                    var item = new ListViewItem();
                    item.Tag = info;
                    item.ImageKey = "plugin";
                    item.SubItems.Add(info.Name);
                    item.SubItems.Add(info.Version);
                    item.SubItems.Add(info.ValidFrom);
                    item.SubItems.Add(info.ValidTo);
                    item.SubItems.Add(info.Description);
                    this.lv_Plugins.Items.Add(item);
                }
                this.SetColumnsWidth();
            }
            catch (Exception ex)
            {
                this.HandleError(ex);
            }
        }

        private void SetColumnsWidth()
        {
            this.lv_Plugins.Columns[0].Width = 20;
            this.lv_Plugins.Columns[1].Width = -1;
            this.lv_Plugins.Columns[2].Width = 80;
            this.lv_Plugins.Columns[3].Width = 80;
            this.lv_Plugins.Columns[4].Width = 80;
            this.lv_Plugins.Columns[5].Width = -1;
        }

        private void tsmi_Install_Click(object sender, EventArgs e)
        {
            try
            {
                var dr = this.ofd_Open.ShowDialog();
                if (dr != DialogResult.OK) return;
                this.pluginManager.Install(this.ofd_Open.FileName);
            }
            catch (Exception ex)
            {
                this.HandleError(ex);
            }
            finally
            {
                this.RefreshGui();
            }
        }

        private void tsmi_OpenPluginRepository_Click(object sender, EventArgs e)
        {
            try
            {
                Process.Start(this.pluginManager.RepositoryPath);
            }
            catch (Exception ex)
            {
                HandleError(ex);
            }
        }

        private void tsmi_Quit_Click(object sender, EventArgs e)
        {
            this.Close();
        }

        private void tsmi_Refresh_Click(object sender, EventArgs e)
        {
            this.RefreshGui();
        }

        private void tsmi_Uninstall_Click(object sender, EventArgs e)
        {
            try
            {
                var dr = MessageBoxes.Question("Do you want to uninstall this plugin?");
                if (dr == DialogResult.No) return;

                var plugin = (PluginManager.PluginInfo)this.lv_Plugins.SelectedItems[0].Tag;
                this.pluginManager.Uninstall(plugin);
                this.RefreshGui();
            }
            catch (Exception ex)
            {
                this.HandleError(ex);
            }
            finally
            {
                this.RefreshGui();
            }
        }

        #endregion Methods
    }
}