﻿namespace Phoenix.Presenter.Interfaces.Input
{
    using System;

    using Phoenix.Model.Bll.Domain;
    using Phoenix.Presenter.Helpers;

    #region Enumerations

    /// <summary>
    /// Indicate where the validation failed
    /// </summary>
    public enum PracticeFailedOn
    {
        /// <summary>
        /// A practice can't be without name.
        /// </summary>
        EmptyTitle,
        /// <summary>
        /// This item is referenced somewhere else in the domain
        /// </summary>
        Referenced,
    }

    #endregion Enumerations

    public interface IPracticeInputPresenter
    {
        #region Events

        /// <summary>
        /// Occurs when user asked to delete an Practice
        /// </summary>
        event EventHandler Deleted;

        /// <summary>
        /// Occurs when user asked to insert an Practice
        /// </summary>
        event EventHandler Inserted;

        /// <summary>
        /// Occurs when user asked to update an Practice
        /// </summary>
        event EventHandler Updated;

        #endregion Events

        #region Properties

        /// <summary>
        /// Gets or sets the item to manage.
        /// </summary>
        /// <value>The item to manage.</value>
        Practice ItemToManage
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the usage of this GUI item.
        /// Should be Insert, Update or Delete.
        /// </summary>
        /// <value>The usage.</value>
        Usage Usage
        {
            get;
            set;
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Clears previous error on validation failed.
        /// </summary>
        void ClearError();

        /// <summary>
        /// Sets an error message on validation failed.
        /// </summary>
        /// <param name="fail">Indicates where the validation failed.</param>
        /// <param name="message">The message to display.</param>
        void SetError(PracticeFailedOn fail, string message);

        #endregion Methods
    }
}