﻿namespace Phoenix.View.Frame.Controls
{
    using System;
    using System.Collections.Generic;
    using System.Drawing;
    using System.Reflection;
    using System.Windows.Forms;

    using log4net;

    using Phoenix.Helpers.Misc;

    /// <summary>
    /// Credits viewer
    /// </summary>
    public partial class CreditsViewer : UserControl
    {
        #region Fields

        private const string COUNTER = "of {0}";

        private List<TeamMember> credits = new List<TeamMember>();
        private int index = 0;
        private ILog logger = LogManager.GetLogger(typeof(CreditsViewer));

        #endregion Fields

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="CreditsViewer"/> class.
        /// </summary>
        public CreditsViewer()
        {
            InitializeComponent();
        }

        #endregion Constructors

        #region Events

        /// <summary>
        /// Occurs when a click occured on the Next or Previous button.
        /// </summary>
        public event EventHandler Navigated;

        #endregion Events

        #region Methods

        /// <summary>
        /// Adds a new person in the credits.
        /// </summary>
        /// <param name="temMember">The card.</param>
        public void Add(TeamMember temMember)
        {
            this.credits.Add(temMember);
            Display();
        }

        /// <summary>
        /// Goes to the next team member.
        /// </summary>
        public void Next()
        {
            if (++this.index > this.credits.Count - 1)
                this.index = 0;
            this.Display();
        }

        /// <summary>
        /// Goes to the previous team member.
        /// </summary>
        public void Previous()
        {
            if (--this.index < 0)
                this.index = this.credits.Count - 1;
            this.Display();
        }

        private void btn_Next_Click(object sender, System.EventArgs e)
        {
            this.Next();
            this.Navigated.Raise(this);
        }

        private void btn_Previous_Click(object sender, System.EventArgs e)
        {
            this.Previous();
            this.Navigated.Raise(this);
        }

        private void Display()
        {
            this.lbl_FirstName.Text = this.credits[this.index].FirstName;
            this.lbl_Function.Text = this.credits[this.index].Function;
            this.lbl_LastName.Text = this.credits[this.index].LastName;
            this.llb_Website.Text = this.credits[this.index].Website;
            this.pb_Picture.Image = this.credits[this.index].Picture;
        }

        private void llb_Website_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            try
            {
                System.Diagnostics.Process.Start(this.llb_Website.Text);
            }
            catch (Exception ex)
            {
                this.logger.Error("Impossible to execute the url form the credits", ex);
            }
        }

        #endregion Methods

        #region Nested Types

        /// <summary>
        /// Represent a member of the nDoctor team
        /// </summary>
        public class TeamMember
        {
            #region Constructors

            /// <summary>
            /// Initializes a new instance of the <see cref="TeamMember"/> class.
            /// </summary>
            public TeamMember()
            {
                this.Picture = ResourceHelper.GetImage(Assembly.GetCallingAssembly(), "Resources.face.gif");
            }

            #endregion Constructors

            #region Properties

            /// <summary>
            /// Gets or sets the first name if the person
            /// </summary>
            /// <value>The first name.</value>
            public string FirstName
            {
                get;
                set;
            }

            /// <summary>
            /// Gets or sets the function if the person
            /// </summary>
            /// <value>The function.</value>
            public string Function
            {
                get;
                set;
            }

            /// <summary>
            /// Gets or sets the last name if the person
            /// </summary>
            /// <value>The last name.</value>
            public string LastName
            {
                get;
                set;
            }

            /// <summary>
            /// Gets or sets the picture.
            /// </summary>
            /// <value>The picture.</value>
            public Image Picture
            {
                get;
                set;
            }

            /// <summary>
            /// Gets or sets the website of the person.
            /// </summary>
            /// <value>The website.</value>
            public string Website
            {
                get;
                set;
            }

            #endregion Properties
        }

        #endregion Nested Types
    }
}