﻿namespace Phoenix.View.Input
{
    using System;
    using System.Drawing;
    using System.Windows.Forms;

    using Phoenix.Helpers.Misc;
    using Phoenix.Helpers.Winforms;

    /// <summary>
    /// 
    /// </summary>
    public partial class PictureInput : UserControl
    {
        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="PictureInput"/> class.
        /// </summary>
        public PictureInput()
            : this(true)
        {
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="PictureInput"/> class.
        /// </summary>
        /// <param name="showError">if set to <c>true</c> [show error].</param>
        public PictureInput(bool showError)
        {
            InitializeComponent();
            this.ShowError = ShowError;
        }

        #endregion Constructors

        #region Properties

        /// <summary>
        /// Gets or sets a value indicating whether the user can manually change the image of the picture box.
        /// </summary>
        /// <value>
        /// 	<c>true</c> if this instance can change image; otherwise, <c>false</c>.
        /// </value>
        public bool CanChangeImage
        {
            get
            {
                return this.llbl_Open.Visible;
            }
            set
            {
                this.llbl_Open.Visible = value;
            }
        }

        /// <summary>
        /// Gets or sets the image.
        /// </summary>
        /// <value>The image.</value>
        public Image Image
        {
            get
            {
                return this.pb_Image.Image;
            }
            set
            {
                this.pb_Image.Image = value;
            }
        }

        /// <summary>
        /// Gets or sets a value indicating whether [show error].
        /// </summary>
        /// <value><c>true</c> if [show error]; otherwise, <c>false</c>.</value>
        public bool ShowError
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the title.
        /// </summary>
        /// <value>The title.</value>
        public string Title
        {
            get
            {
                return this.lbl_Name.Text;
            }
            set
            {
                this.lbl_Name.Text = value;
            }
        }

        #endregion Properties

        #region Methods

        private void llbl_Open_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            var dr = this.ofd_OpenFile.ShowDialog();
            if (dr != DialogResult.OK) return;

            try
            {
                using (var img = Image.FromFile(this.ofd_OpenFile.FileName))
                {
                    var size = this.pb_Image.Size;
                    this.pb_Image.Image = img.GetThumbnailImage(size.Height, size.Width);
                }
            }
            catch (Exception ex)
            {
            #if DEBUG
                MessageBoxes.Asterisk(ex);
            #else
                MessageBoxes.Asterisk("Impossible to open the image");
                if (this.ShowError) throw new Exception("Impossible to open the image", ex);
            #endif
            }
        }

        #endregion Methods
    }
}