﻿namespace Phoenix.Helpers.Misc
{
    using System;
    using System.Diagnostics;

    /// <summary>
    /// Provides EventArgs that contains a generic value
    /// </summary>
    /// <typeparam name="T"></typeparam>
    public class EventArgs<T> : EventArgs
    {
        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="EventArgs&lt;T&gt;"/> class.
        /// </summary>
        /// <param name="value">The value.</param>
        [DebuggerStepThrough]
        public EventArgs(T value)
        {
            this.Data = value;
        }

        #endregion Constructors

        #region Properties

        /// <summary>
        /// Gets or the value of the EventArgs.
        /// </summary>
        /// <value>The value.</value>
        public T Data
        {
            get;
            private set;
        }

        #endregion Properties
    }

    /// <summary>
    /// Provides EventArgs that contains a generic value
    /// </summary>
    /// <typeparam name="T">First value type</typeparam>
    /// <typeparam name="U">Second value type</typeparam>
    public class EventArgs<T, U> : EventArgs
    {
        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="EventArgs&lt;T, U&gt;"/> class.
        /// </summary>
        /// <param name="data1">The data1.</param>
        /// <param name="data2">The data2.</param>
        public EventArgs(T data1, U data2)
        {
            this.Data1 = data1;
            this.Data2 = data2;
        }

        #endregion Constructors

        #region Properties

        /// <summary>
        /// Gets the data1.
        /// </summary>
        /// <value>The data1.</value>
        public T Data1
        {
            get; private set;
        }

        /// <summary>
        /// Gets data2.
        /// </summary>
        /// <value>The data2.</value>
        public U Data2
        {
            get; private set;
        }

        #endregion Properties
    }
}